#include "particle.h"
#include "ofMain.h"


//------------------------------------------------------------
particle::particle(){
	setInitialCondition(0,0,0,0);
	damping = 0.01f;
}

//------------------------------------------------------------
void particle::resetForce(){
    // we reset the forces every frame
    frc.set(0,0);
}

//------------------------------------------------------------
void particle::addForce(float x, float y){
    // add in a force in X and Y for this frame.
    frc.x = frc.x + x;
    frc.y = frc.y + y;
}

//------------------------------------------------------------
void particle::addDampingForce(){
	
	// the usual way to write this is  vel *= 0.99
	// basically, subtract some part of the velocity 
	// damping is a force operating in the oposite direction of the 
	// velocity vector
	
    frc.x = frc.x - vel.x * damping;
    frc.y = frc.y - vel.y * damping;
}

//------------------------------------------------------------
void particle::setInitialCondition(float px, float py, float vx, float vy){
    pos.set(px,py);
	vel.set(vx,vy);
}

//------------------------------------------------------------
void particle::update(){	
	vel = vel + frc;
	pos = pos + vel;

}

//------------------------------------------------------------
void particle::draw(ofImage * picture){
    //ofCircle(pos.x, pos.y, 3);
	ofSetColor(255, 255, 255);
	ofPushMatrix();

	ofTranslate(pos.x, pos.y, 5);
	//ofTranslate(pos.x+vel.x*100, pos.y+vel.y*100, 5);
	
	ofRotateZ(vel.x*15 * RAD_TO_DEG);
	
	picture->draw(-vel.x*100, -vel.x*100, vel.x*200, vel.x*200);
	ofPopMatrix();
}

